summaryrefslogtreecommitdiffhomepage
path: root/packages/typescript-types/src
diff options
context:
space:
mode:
authorMatthew Miller <matthew@millerti.me>2020-05-20 23:37:27 -0700
committerMatthew Miller <matthew@millerti.me>2020-05-20 23:37:27 -0700
commite9cb351795ca31b583be534b3347376e61b1c2c3 (patch)
treecd9ab2aea7b4dfa89fed9c05aa302f1f2333b115 /packages/typescript-types/src
parent1bf99eca9c356fc41f520491d96963438a18ce00 (diff)
Rename some types
Diffstat (limited to 'packages/typescript-types/src')
-rw-r--r--packages/typescript-types/src/index.ts8
1 files changed, 4 insertions, 4 deletions
diff --git a/packages/typescript-types/src/index.ts b/packages/typescript-types/src/index.ts
index 4411fec..8ab5763 100644
--- a/packages/typescript-types/src/index.ts
+++ b/packages/typescript-types/src/index.ts
@@ -1,5 +1,5 @@
/**
* A variant of AttestationCredentials suitable for JSON transmission to the browser to
* (eventually) get passed into navigator.credentials.create(...) in the browser.
*
* Noteworthy values:
@@ -7,7 +7,7 @@
* @param user.id Your unique, internal ID for the user. Will be converted to a Uint8Array in the
* browser
*/
-export type AttestationCredentialsJSON = {
+export type PublicKeyCredentialCreationOptionsJSON = {
publicKey: {
challenge: string,
// The organization registering and authenticating the user
@@ -30,7 +30,7 @@ export type AttestationCredentialsJSON = {
};
/**
* A variant of AssertionCredentials suitable for JSON transmission to the browser to
* (eventually) get passed into navigator.credentials.get(...) in the browser.
*
* Noteworthy values:
@@ -38,7 +38,7 @@ export type AttestationCredentialsJSON = {
* @param allowCredentials.id Base64-encoded credentialId. Will be converted to a Uint8Array in the
* browser
*/
-export type AssertionCredentialsJSON = {
+export type PublicKeyCredentialRequestOptionsJSON = {
publicKey: {
//
challenge: string,
@@ -1,5 +1,5 @@
/**
- * A variant of AttestationCredentials suitable for JSON transmission to the browser to
+ * A variant of PublicKeyCredentialCreationOptions suitable for JSON transmission to the browser to
* (eventually) get passed into navigator.credentials.create(...) in the browser.
*
@@ -30,7 +30,7 @@ export type AttestationCredentialsJSON = {
};
/**
- * A variant of AssertionCredentials suitable for JSON transmission to the browser to
+ * A variant of PublicKeyCredentialRequestOptions suitable for JSON transmission to the browser to
* (eventually) get passed into navigator.credentials.get(...) in the browser.
*